@@ -14,15 +14,13 @@ class McsAPI(ApiClient):
 
     def get_jwt_token(self, wallet_address, private_key, chain_name):
         nonce = self.user_register(wallet_address)["data"]["nonce"]
-        print(nonce)
         message = encode_defunct(text=nonce)
         signed_message = Account.sign_message(message, private_key=private_key)["signature"]
         signature = web3.Web3.toHex(signed_message)
-        print(signature)
-        # login = self.user_login(wallet_address, signature, nonce, chain_name)
-        # jwt = login["data"]["jwt_token"]
-        # self.token = jwt
-        # return jwt
+        login = self.user_login(wallet_address, signature, nonce, chain_name)
+        jwt = login["data"]["jwt_token"]
+        self.token = jwt
+        return jwt
 
     def get_params(self):
         return self._request_without_params(GET, MCS_PARAMS, self.MCS_API, self.token)
@@ -30,22 +28,22 @@ class McsAPI(ApiClient):
     def get_price_rate(self):
         return self._request_without_params(GET, PRICE_RATE, self.MCS_API, self.token)
 
-    def get_payment_info(self, payload_cid, wallet_address, source_file_upload_id):
+    def get_payment_info(self, source_file_upload_id):
         params = {}
-        if payload_cid:
-            params['payload_cid'] = payload_cid
-        if wallet_address:
-            params['wallet_address'] = wallet_address
-        if wallet_address:
+        if source_file_upload_id:
             params['source_file_upload_id'] = source_file_upload_id
         return self._request_with_params(GET, PAYMENT_INFO, self.MCS_API, params, self.token, None)
 
-    def get_user_tasks_deals(self, wallet_address, file_name=None):
+    def get_user_tasks_deals(self, page_number=None, page_size=None, file_name=None, status=None):
         params = {}
-        if wallet_address:
-            params['wallet_address'] = wallet_address
+        if page_number:
+            params['page_number'] = page_number
+        if page_size:
+            params['page_size'] = page_size
         if file_name:
             params['file_name'] = file_name
+        if status:
+            params['status'] = status
         return self._request_with_params(GET, TASKS_DEALS, self.MCS_API, params, self.token, None)
 
     def get_mint_info(self, source_file_upload_id, payload_cid, tx_hash, token_id, mint_address):
@@ -75,10 +73,8 @@ class McsAPI(ApiClient):
             params['file'] = (file_path, open(file_path, 'rb'))
         return self._request_stream_upload(UPLOAD_FILE, self.MCS_API, params, self.token)
 
-    def get_deal_detail(self, wallet_address, source_file_upload_id, deal_id='0'):
+    def get_deal_detail(self, source_file_upload_id, deal_id='0'):
         params = {}
-        if wallet_address:
-            params['wallet_address'] = wallet_address
         if source_file_upload_id:
             params['source_file_upload_id'] = source_file_upload_id
         return self._request_with_params(GET, DEAL_DETAIL + deal_id, self.MCS_API, params, self.token, None)
@@ -117,4 +113,4 @@ class McsAPI(ApiClient):
             params['nonce'] = nonce
             params['signature'] = signature
             params['network'] = network
-        return self._request_with_params(POST, USER_LOGIN, self.MCS_API, params, None, None)
+        return self._request_with_params(POST, USER_LOGIN, self.MCS_API, params, None, None)
\ No newline at end of file
